.. asaman documentation master file, created by
   sphinx-quickstart on Tue Oct  5 10:36:13 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to asaman's documentation!
==================================

**আমরা সমান: We are same**. A tool to create reproducible wheels for Python packages. 

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   usage
   hacking

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
